@@ -23,18 +23,21 @@ AUC = Qt.AutoConnection | Qt.UniqueConnection
 MW = None
 
 
+def safeTranslate(qApp, group, text):
+    try:
+        return qApp.translate(group, text)
+    except:
+        return text
+
 def wordCount(text):
-    t = text.strip().replace(" ", "\n").split("\n")
-    t = [l for l in t if l]
-    return len(t)
+    return len(re.findall(r"\S+", re.sub(r"(<!--).+?(-->)", "", text, flags=re.DOTALL)))
+
 
 def charCount(text, use_spaces = True):
-    t = text.strip()
-
-    if not use_spaces:
-        t = t.replace(" ", "")
-
-    return len(t)
+    if use_spaces:
+        return len(re.findall(r"[\S ]", text))
+    else:
+        return len(re.findall(r"\S", text))
 
 validate_ok = lambda *args, **kwargs: True
 def uiParse(input, default, converter, validator=validate_ok):
@@ -92,7 +95,7 @@ def drawProgress(painter, rect, progress, radius=0):
     painter.setBrush(QBrush(colorFromProgress(progress)))
 
     r2 = QRect(rect)
-    r2.setWidth(r2.width() * min(progress, 1))
+    r2.setWidth(int(r2.width() * min(progress, 1)))
     painter.drawRoundedRect(r2, radius, radius)
 
 
@@ -175,24 +178,25 @@ def randomColor(mix=None):
     b = randint(0, 255)
 
     if mix:
-        r = (r + mix.red()) / 2
-        g = (g + mix.green()) / 2
-        b = (b + mix.blue()) / 2
+        r = int((r + mix.red()) / 2)
+        g = int((g + mix.green()) / 2)
+        b = int((b + mix.blue()) / 2)
 
     return QColor(r, g, b)
 
 
-def mixColors(col1, col2, f=.5):
+def mixColors(col1, col2, f=0.5):
     fromString = False
     if type(col1) == str:
         fromString = True
         col1 = QColor(col1)
     if type(col2) == str:
         col2 = QColor(col2)
-    f2 = 1-f
-    r = col1.red() * f + col2.red() * f2
-    g = col1.green() * f + col2.green() * f2
-    b = col1.blue() * f + col2.blue() * f2
+
+    f2 = 1.0 - f
+    r = int(col1.red() * f + col2.red() * f2)
+    g = int(col1.green() * f + col2.green() * f2)
+    b = int(col1.blue() * f + col2.blue() * f2)
 
     return QColor(r, g, b) if not fromString else QColor(r, g, b).name()
 
@@ -248,7 +252,7 @@ def colorifyPixmap(pixmap, color):
 
 
 def appPath(suffix=None):
-    p = os.path.realpath(os.path.join(os.path.split(__file__)[0], "../.."))
+    p = os.path.realpath(os.path.join(os.path.split(__file__)[0], os.path.join("..", "..")))
     if suffix:
         p = os.path.join(p, suffix)
     return p
@@ -301,7 +305,7 @@ def findBackground(filename):
     """
     Returns the full path to a background file of name filename within resources folders.
     """
-    return findFirstFile(re.escape(filename), "resources/backgrounds")
+    return findFirstFile(re.escape(filename), os.path.join("resources", "backgrounds"))
 
 
 def findFirstFile(regex, path="resources"):
@@ -407,7 +411,7 @@ def statusMessage(message, duration=5000, importance=1):
     MW.statusLabel.adjustSize()
     g = MW.statusLabel.geometry()
     # g.moveCenter(MW.mapFromGlobal(MW.geometry().center()))
-    s = MW.layout().spacing() / 2
+    s = int(MW.layout().spacing() / 2)
     g.setLeft(s)
     g.moveBottom(MW.mapFromGlobal(MW.geometry().bottomLeft()).y() - s)
     MW.statusLabel.setGeometry(g)
@@ -465,7 +469,7 @@ def search(searchRegex, text):
     :return:                list of tuples (startPos, endPos)
     """
     if text is not None:
-        return [(m.start(), m.end(), getSearchResultContext(text, m.start(), m.end())) for m in searchRegex.finditer(text)]
+        return [(m.start(), m.end(), getSearchResultContext(text, m.start(), m.end())) for m in searchRegex.finditer(str(text))]
     else:
         return []
 
@@ -507,7 +511,7 @@ def getManuskriptPath(follow_symlinks=True):
         path = os.path.abspath(sys.executable)
     else:
         import inspect
-        path = inspect.getabsfile(getManuskriptPath) + "/../.."
+        path = os.path.join(inspect.getabsfile(getManuskriptPath), "..", "..")
     if follow_symlinks:
         path = os.path.realpath(path)
     return os.path.dirname(path)
